@@ -1,4 +1,4 @@
-/* Copyright 2023 VMware, Inc.
+/* Copyright 2024 VMware, Inc.
  * SPDX-License-Identifier: Apache-2.0
  */
 
@@ -245,7 +245,7 @@ int parse_yaml_rf_online(const char *key,
         assert(node);
 
         family = (char **) userdata;
-        r = address_family_name_to_type(value);
+        r = required_address_family_for_online_name_to_type(value);
         if(r < 0) {
                 log_warning("Failed to parse RequiredFamilyForOnline: %s", value);
                 return -EINVAL;
@@ -277,7 +277,7 @@ int parse_yaml_activation_policy(const char *key,
         activation_policy = (char **) userdata;
         r = device_activation_policy_name_to_type(value);
         if (r < 0) {
-                log_warning("Failed to parse activation-mode='%s': %s", value, strerror(EINVAL));
+                log_warning("Failed to parse ActivationPolicy='%s': %s", value, strerror(EINVAL));
                 return r;
         }
 
@@ -350,13 +350,13 @@ int parse_yaml_dhcp_client_identifier(const char *key,
 
         n = data;
 
-        r = dhcp_client_identifier_to_mode((char *) value);
+        r = dhcp_client_identifier_to_kind((char *) value);
         if (r < 0) {
-                log_warning("Failed to parse dhcp client identifier='%s'\n", value);
+                log_warning("Failed to parse dhcp client identifier='%s'", value);
                 return r;
         }
 
-        n->dhcp_client_identifier_type = dhcp_client_identifier_to_mode((char *) value);
+        n->dhcp_client_identifier_type = dhcp_client_identifier_to_kind((char *) value);
         return 0;
 }
 
@@ -413,9 +413,9 @@ int parse_yaml_link_local_type(const char *key,
 
         n = data;
 
-        r = link_local_address_type_to_mode((const char *) value);
+        r = link_local_address_type_to_kind((const char *) value);
         if (r < 0) {
-                log_warning("Failed to parse link local address type='%s'\n", value);
+                log_warning("Failed to parse link local address type='%s'", value);
                 return r;
         }
         n->link_local = r;
@@ -441,7 +441,7 @@ int parse_yaml_keep_configuration(const char *key,
 
         r = keep_configuration_type_to_mode((const char *) value);
         if (r < 0) {
-                log_warning("Failed to parse keep configuration mode='%s'\n", value);
+                log_warning("Failed to parse keep configuration mode='%s'", value);
                 return r;
         }
         n->keep_configuration = r;
@@ -467,7 +467,7 @@ int parse_yaml_ipv6_address_generation_mode(const char *key,
 
         r = ipv6_link_local_address_gen_type_to_mode((const char *) value);
         if (r < 0) {
-                log_warning("Failed to parse IPv6 link local address generation mode='%s'\n", value);
+                log_warning("Failed to parse IPv6 link local address generation mode='%s'", value);
                 return r;
         }
         n->ipv6_address_generation = r;
@@ -493,7 +493,7 @@ int parse_yaml_infiniband_mode(const char *key,
 
         r = ipoib_name_to_mode((const char *) value);
         if (r < 0) {
-                log_warning("Failed to parse ipoib mode='%s'\n", value);
+                log_warning("Failed to parse ipoib mode='%s'", value);
                 return r;
         }
         n->ipoib_mode = r;
@@ -519,7 +519,7 @@ int parse_yaml_dhcp6_without_ra(const char *key,
 
         r = dhcp6_client_start_name_to_mode((const char *) value);
         if (r < 0) {
-                log_warning("Failed to parse DHCP6 client start mode='%s'\n", value);
+                log_warning("Failed to parse DHCP6 client start mode='%s'", value);
                 return r;
         }
         n->dhcp6_client_start_mode = r;
@@ -546,7 +546,7 @@ int parse_yaml_ipv6_privacy_extensions(const char *key,
 
         r = ipv6_privacy_extensions_to_type((const char *) value);
         if (r < 0) {
-                log_warning("Failed to parse IPv6 Privacy extension='%s'\n", value);
+                log_warning("Failed to parse IPv6PrivacyExtension='%s'", value);
                 return r;
         }
         n->ipv6_privacy = r;
@@ -572,7 +572,7 @@ int parse_yaml_bond_mode(const char *key,
 
         r = bond_name_to_mode((const char *) value);
         if (r < 0) {
-                log_warning("Failed to parse Bond mode='%s'\n", value);
+                log_warning("Failed to parse Bond mode='%s'", value);
                 return r;
         }
         b->mode = r;
@@ -598,7 +598,7 @@ int parse_yaml_macvlan_mode(const char *key,
 
         r = macvlan_name_to_mode((const char *) value);
         if (r < 0) {
-                log_warning("Failed to parse MACVLAN mode='%s'\n", value);
+                log_warning("Failed to parse MACVLAN mode='%s'", value);
                 return r;
 
         }
@@ -627,7 +627,7 @@ int parse_yaml_address(const char *key,
 
         r = parse_ip_from_str(value, &address);
         if (r < 0) {
-                log_warning("Failed to parse address %s = %s", key, value);
+                log_warning("Failed to parse address='%s': %s", key, value);
                 return r;
         }
 
@@ -740,7 +740,7 @@ int parse_yaml_scalar_or_sequence(const char *key,
         assert(doc);
         assert(node);
 
-        if (!isempty_str(key) && !isempty_str(value)) {
+        if (!isempty(key) && !isempty(value)) {
                 *s = strv_new(value);
                 if (!*s)
                         return -ENOMEM;
@@ -754,18 +754,14 @@ int parse_yaml_scalar_or_sequence(const char *key,
                 if (!c)
                         return log_oom();
 
-                if (!*s) {
-                        *s = strv_new(c);
-                        if (!*s)
-                                return log_oom();
-                } else {
-                        if (!strv_contains((const char **)*s, c)) {
-                                r = strv_add(s, c);
-                                if (r < 0)
-                                        return r;
-                        }
-                }
-       }
+                if (!*s)
+                        r = strv_extend(s, c);
+                else  if (!strv_contains((const char **)*s, c))
+                        r = strv_extend(s, c);
+
+                if (r < 0)
+                        return r;
+        }
 
         return 0;
 }
@@ -793,17 +789,13 @@ int parse_yaml_sequence(const char *key,
                 if (!c)
                         return log_oom();
 
-                if (!*s) {
-                        *s = strv_new(c);
-                        if (!*s)
-                                return log_oom();
-                } else {
-                        if (!strv_contains((const char **)*s, c)) {
-                                r = strv_add(s, c);
-                                if (r < 0)
-                                        return r;
-                        }
-                }
+                if (!*s)
+                        r = strv_extend(s, c);
+                else  if (!strv_contains((const char **)*s, c))
+                        r = strv_extend(s, c);
+
+                if (r < 0)
+                        return r;
         }
 
         return 0;
@@ -881,7 +873,7 @@ int parse_yaml_route_type(const char *key,
 
         r = route_type_to_mode(value);
         if (r < 0) {
-                log_warning("Failed to parse route type='%s'\n", value);
+                log_warning("Failed to parse route type='%s'", value);
                 return r;
         }
         rt->type = r;
@@ -908,7 +900,7 @@ int parse_yaml_route_scope(const char *key,
 
         r = route_scope_type_to_mode(value);
         if (r < 0) {
-                log_warning("Failed to parse route scope='%s'\n", value);
+                log_warning("Failed to parse route scope='%s'", value);
                 return r;
         }
         rt->scope = r;
@@ -1070,7 +1062,7 @@ int parse_yaml_bond_lacp_rate(const char *key,
 
         r = bond_lacp_rate_to_mode(value);
         if (r < 0) {
-                log_warning("Failed to parse bond lacp rate type='%s'\n", value);
+                log_warning("Failed to parse bond lacp rate type='%s'", value);
                 return r;
         }
 
@@ -1098,7 +1090,7 @@ int parse_yaml_bond_arp_validate(const char *key,
 
         r = bond_arp_validate_table_name_to_mode(value);
         if (r < 0) {
-                log_warning("Failed to parse bond arp validate type='%s'\n", value);
+                log_warning("Failed to parse bond arp validate type='%s'", value);
                 return r;
         }
 
@@ -1126,7 +1118,7 @@ int parse_yaml_bond_fail_over_mac(const char *key,
 
         r = bond_fail_over_mac_name_to_mode(value);
         if (r < 0) {
-                log_warning("Failed to parse bond fail over mac type='%s'\n", value);
+                log_warning("Failed to parse bond fail over mac type='%s'", value);
                 return r;
         }
 
@@ -1154,7 +1146,7 @@ int parse_yaml_bond_ad_select(const char *key,
 
         r = bond_ad_select_name_to_mode(value);
         if (r < 0) {
-                log_warning("Failed to parse bond fail over mac type='%s'\n", value);
+                log_warning("Failed to parse bond fail over mac type='%s'", value);
                 return r;
         }
 
@@ -1182,7 +1174,7 @@ int parse_yaml_bond_primary_reselect(const char *key,
 
         r = bond_primary_reselect_name_to_mode(value);
         if (r < 0) {
-                log_warning("Failed to parse bond primary reselect type='%s'\n", value);
+                log_warning("Failed to parse bond primary reselect type='%s'", value);
                 return r;
         }
 
@@ -1210,7 +1202,7 @@ int parse_yaml_bond_xmit_hash_policy(const char *key,
 
         r = bond_xmit_hash_policy_name_to_mode(value);
         if (r < 0) {
-                log_warning("Failed to parse bond xmit hash policy type='%s'\n", value);
+                log_warning("Failed to parse bond xmit hash policy type='%s'", value);
                 return r;
         }
 
@@ -1317,7 +1309,7 @@ int parse_yaml_bridge_path_cost(const char *key,
 
                 r = parse_uint32(scalar(v), &t);
                 if (r < 0) {
-                        log_warning("Failed to parse bridge cost='%s'\n", scalar(v));
+                        log_warning("Failed to parse bridge cost='%s'", scalar(v));
                         return r;
                 }
 
@@ -1361,7 +1353,7 @@ int parse_yaml_bridge_port_priority(const char *key,
 
                 r = parse_uint16(scalar(v), &t);
                 if (r < 0) {
-                        log_warning("Failed to parse bridge cost='%s'\n", scalar(v));
+                        log_warning("Failed to parse bridge cost='%s'", scalar(v));
                         return r;
                 }
 
